webbpsf\_ext.coords.jwst\_point
===============================

.. currentmodule:: webbpsf_ext.coords

.. autoclass:: jwst_point
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~jwst_point.__init__
      ~jwst_point.ap_radec
      ~jwst_point.attitude_matrix
      ~jwst_point.frame_to_radec
      ~jwst_point.gen_random_offsets
      ~jwst_point.plot_inst_apertures
      ~jwst_point.plot_main_apertures
      ~jwst_point.plot_obs_aperture
      ~jwst_point.plot_ref_aperture
      ~jwst_point.radec_to_frame
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~jwst_point.base_std
      ~jwst_point.dith_std
      ~jwst_point.exp_nums
      ~jwst_point.ndith
   
   